'use client'

import { useJoin } from 'agora-rtc-react';
import { useEffect, useState } from 'react';
import { MediaControl } from './view';
import { LocalUserPanel, RemoteUserPanel } from './components';
import { PublicUser } from '../../../types/sessions';

// const appId = process.env.AGORA_APPID;

type AgoraProps = {
    sessionId: number;
    secret?: string;
    stopCalling: () => void;
    remoteUser?: PublicUser;
};

export const Agora = ({ sessionId, secret, stopCalling, remoteUser }: AgoraProps) => {
    const [calling, setCalling] = useState(false);
    const [micOn, setMic] = useState(false);
    const [cameraOn, setCamera] = useState(false);

    useEffect(() => {
        setCalling(true);
    }, []);

    useJoin(
        {
            appid: 'ed90c9dc42634e5687d4e2e0766b363f',
            channel: `${sessionId}-${secret}`,
            token: null,
        },
        calling,
    );

    const stop = () => {
        stopCalling();
        setCalling(false);
    };

    return (
        <div className="b-agora__wrap">
            <RemoteUserPanel calling={calling} user={remoteUser} />
            <div className="b-agora__panel">
                <MediaControl
                    calling={calling}
                    cameraOn={cameraOn}
                    micOn={micOn}
                    setCalling={stop}
                    setCamera={() => setCamera(a => !a)}
                    setMic={() => setMic(a => !a)}
                />
                <LocalUserPanel
                    calling={calling}
                    cameraOn={cameraOn}
                    micOn={micOn}
                />
            </div>
        </div>
    );
};
